# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs     0
%else
%define build_docs     1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 2

%define qttarballdir qtvirtualkeyboard-everywhere-opensource-src-%{qtversion}

# Library names

%define libqtvirtualkeyboard     %mklibname qt%{qtmajor}virtualkeyboard %{qtmajor}
%define libqthunspellinputmethod %mklibname qt%{qtmajor}hunspellinputmethod %{qtmajor}
%define libqtvirtualkeyboard_d   %mklibname qt%{qtmajor}virtualkeyboard -d

Name:           qtvirtualkeyboard5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} VirtualKeyboard component
# See LGPL_EXCEPTIONS.txt, LICENSE.GPL3, respectively, for exception details
License:        LGPLv2 with exceptions or GPLv3 with exceptions
Group:          Development/KDE and Qt
Url:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

# upstream patches
# https://community.kde.org/Qt5PatchCollection

BuildRequires:  pkgconfig(Qt5Core) >= %{version}
BuildRequires:  pkgconfig(Qt5Gui) >= %{version}
BuildRequires:  pkgconfig(Qt5Qml) >= %{version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{version}
BuildRequires:  pkgconfig(Qt5Svg) >= %{version}
BuildRequires:  pkgconfig(Qt5Widgets) >= %{version}
BuildRequires:  pkgconfig(hunspell)

Provides:       qt%{qtmajor}-qtvirtualkeyboard = %{version}-%{release}

%description
The Qt Virtual Keyboard project provides an input framework and reference
keyboard frontend for Qt 5. Key features include:

* Customizable keyboard layouts and styles with dynamic switching.
* Predictive text input with word selection.
* Character preview and alternative character view.
* Automatic capitalization and space insertion.
* Scalability to different resolutions.
* Support for different character sets (Latin, Simplified/Traditional Chinese,
  Hindi, Japanese, Arabic, Korean, and others).
* Support for most common input languages, with possibility to easily extend
  the language support.
* Left-to-right and right-to-left input.
* Hardware key support for 2-way and 5-way navigation.
* Handwriting support, with gestures for fullscreen input.
* Audio feedback.

%files
%license LICENSE.GPL3
%{_qt5_plugindir}/virtualkeyboard/
%{_qt5_plugindir}/platforminputcontexts/libqtvirtualkeyboardplugin.so
%{_qt5_qml}/QtQuick/VirtualKeyboard/

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtVirtualKeyboard%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtVirtualKeyboard%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt5_docdir}/qtvirtualkeyboard.qch
%{_qt5_docdir}/qtvirtualkeyboard/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtvirtualkeyboard}
Summary:        Qt%{qtmajor} Virtual Keyboard Component Library
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libqtvirtualkeyboard}
Qt%{qtmajor} Virtual Keyboard Component Library.

%files -n %{libqtvirtualkeyboard}
%{_qt5_libdir}/libQt5VirtualKeyboard.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqthunspellinputmethod}
Summary:        Qt%{qtmajor} Hunspell Input Method Component Library
Group:          System/Libraries

%description -n %{libqthunspellinputmethod}
Qt%{qtmajor} Hunspell Input Method Component Library.

%files -n %{libqthunspellinputmethod}
%{_qt5_libdir}/libQt5HunspellInputMethod.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtvirtualkeyboard_d}
Summary:        Devel files needed to build apps based on QtVirtualKeyboard
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}
Requires:       %{libqtvirtualkeyboard} = %{version}
Requires:       %{libqthunspellinputmethod} = %{version}
Provides:       libqtvirtualkeyboard5-devel = %{version}
Provides:       libqt5virtualkeyboard-devel = %{version}
Provides:       qtvirtualkeyboard5-devel = %{version}
Provides:       qt5virtualkeyboard-devel = %{version}

%description -n %{libqtvirtualkeyboard_d}
Devel files needed to build apps based on Qt VirtualKeyboard.

%files -n %{libqtvirtualkeyboard_d}
%{_qt5_includedir}/QtVirtualKeyboard/
%{_qt5_includedir}/QtHunspellInputMethod/
%{_qt5_libdir}/libQt5VirtualKeyboard.so
%{_qt5_libdir}/libQt5HunspellInputMethod.so
%{_qt5_libdir}/libQt5VirtualKeyboard.prl
%{_qt5_libdir}/libQt5HunspellInputMethod.prl
%{_qt5_libdir}/pkgconfig/Qt5VirtualKeyboard.pc
%{_qt5_libdir}/cmake/Qt5VirtualKeyboard/
%{_qt5_libdir}/cmake/Qt5HunspellInputMethod/
%{_qt5_libdir}/cmake/Qt5Gui/Qt5Gui_QVirtualKeyboardPlugin.cmake
%{_qt5_libdir}/qt5/mkspecs/modules/*.pri
%{_qt5_examplesdir}/virtualkeyboard/

#------------------------------------------------------------------------------

%prep
%autosetup -n qtvirtualkeyboard-everywhere-src-%{qtversion} -p1

%build
%qmake_qt5 CONFIG+=lang-all

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif


%changelog
* Tue Jul 01 2025 umeabot <umeabot> 5.15.16-2.mga10
+ Revision: 2234065
- Mageia 10 Mass Rebuild

* Sat Jan 18 2025 daviddavid <daviddavid> 5.15.16-1.mga10
+ Revision: 2139639
- New version 5.15.16

* Tue Jan 09 2024 neoclust <neoclust> 5.15.12-1.mga10
+ Revision: 2029342
- New version 5.15.12

* Fri Dec 09 2022 neoclust <neoclust> 5.15.7-1.mga9
+ Revision: 1920144
- New version 5.15.7

* Sat Sep 10 2022 neoclust <neoclust> 5.15.6-1.mga9
+ Revision: 1886642
- New version 5.15.6

* Sat Aug 27 2022 neoclust <neoclust> 5.15.5-1.mga9
+ Revision: 1881239
- New version 5.15.5

* Mon Apr 04 2022 umeabot <umeabot> 5.15.2-2.mga9
+ Revision: 1843237
- Mageia 9 Mass Rebuild

* Fri Dec 04 2020 daviddavid <daviddavid> 5.15.2-1.mga8
+ Revision: 1652478
- New version 5.15.2

* Sat Sep 12 2020 daviddavid <daviddavid> 5.15.1-1.mga8
+ Revision: 1624925
- New version 5.15.1

* Wed Jun 03 2020 daviddavid <daviddavid> 5.15.0-1.mga8
+ Revision: 1589838
- New version 5.15.0

* Thu Feb 20 2020 umeabot <umeabot> 5.14.1-2.mga8
+ Revision: 1545539
- Mageia 8 Mass Rebuild

* Tue Jan 28 2020 daviddavid <daviddavid> 5.14.1-1.mga8
+ Revision: 1484413
- New version 5.14.1

* Mon Sep 09 2019 neoclust <neoclust> 5.13.1-1.mga8
+ Revision: 1438749
- New version 5.13.1

* Sun Jul 14 2019 neoclust <neoclust> 5.13.0-2.mga8
+ Revision: 1421133
- Rebuild for new mkspecs macros

* Thu Jul 04 2019 daviddavid <daviddavid> 5.13.0-1.mga8
+ Revision: 1418159
- New version 5.13.0

* Mon Apr 01 2019 umeabot <umeabot> 5.12.2-2.mga7
+ Revision: 1384575
- Qt5 Rebuild

* Mon Mar 18 2019 neoclust <neoclust> 5.12.2-1.mga7
+ Revision: 1378552
- New version 5.12.2

* Fri Feb 01 2019 neoclust <neoclust> 5.12.1-1.mga7
+ Revision: 1362297
- New version 5.12.1

* Thu Dec 13 2018 neoclust <neoclust> 5.12.0-1.mga7
+ Revision: 1341028
- New version 5.12.0

* Fri Nov 23 2018 daviddavid <daviddavid> 5.11.2-4.mga7
+ Revision: 1333477
- rebuild for new hunspell 1.7.0

* Sun Nov 18 2018 daviddavid <daviddavid> 5.11.2-3.mga7
+ Revision: 1330814
- use upstream patch to be more restrictive about which information
  is included in logging

* Thu Oct 25 2018 daviddavid <daviddavid> 5.11.2-2.mga7
+ Revision: 1325178
- do not log keypresses in release mode

* Tue Oct 09 2018 neoclust <neoclust> 5.11.2-1.mga7
+ Revision: 1319041
- New version 5.11.2

* Sun Sep 23 2018 umeabot <umeabot> 5.11.1-2.mga7
+ Revision: 1300732
- Mageia 7 Mass Rebuild

* Sun Jul 29 2018 neoclust <neoclust> 5.11.1-1.mga7
+ Revision: 1245827
- New version 5.11.1

* Fri May 25 2018 neoclust <neoclust> 5.11.0-1.mga7
+ Revision: 1232126
- New version 5.11.0

* Mon Apr 09 2018 neoclust <neoclust> 5.10.1-1.mga7
+ Revision: 1216521
- New version 5.10.1

* Thu Mar 01 2018 neoclust <neoclust> 5.9.4-1.mga7
+ Revision: 1205938
- New version 5.9.4

* Sat Dec 30 2017 daviddavid <daviddavid> 5.9.3-1.mga7
+ Revision: 1187570
- New version 5.9.3
+ neoclust <neoclust>
- New version 5.9.3

* Wed Aug 09 2017 daviddavid <daviddavid> 5.9.1-2.mga7
+ Revision: 1139297
- enable hunspell support

* Wed Aug 09 2017 daviddavid <daviddavid> 5.9.1-1.mga7
+ Revision: 1139289
- initial package qtvirtualkeyboard5

